==> kubernetes-model-1.0.50-sources.jar: io/fabric8/kubernetes/api/model/ConfigMapKeySelectorBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;

public class ConfigMapKeySelectorBuilder extends ConfigMapKeySelectorFluentImpl<ConfigMapKeySelectorBuilder> implements VisitableBuilder<ConfigMapKeySelector,ConfigMapKeySelectorBuilder>{

     ConfigMapKeySelectorFluent<?> fluent;
public ConfigMapKeySelectorBuilder(){
    this(new ConfigMapKeySelector());
}
public ConfigMapKeySelectorBuilder( ConfigMapKeySelectorFluent<?> fluent ){
    this(fluent, new ConfigMapKeySelector());
}
public ConfigMapKeySelectorBuilder( ConfigMapKeySelectorFluent<?> fluent , ConfigMapKeySelector instance ){
    this.fluent = fluent; fluent.withKey(instance.getKey()); fluent.withName(instance.getName()); 
}
public ConfigMapKeySelectorBuilder( ConfigMapKeySelector instance ){
    this.fluent = this; this.withKey(instance.getKey()); this.withName(instance.getName()); 
}

public ConfigMapKeySelector build(){
    ConfigMapKeySelector buildable = new ConfigMapKeySelector(fluent.getKey(),fluent.getName());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
ConfigMapKeySelectorBuilder that = (ConfigMapKeySelectorBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    Validator validator = null;
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    } catch(ValidationException e) {
        //ignore
        return;
    }

    Set<ConstraintViolation<T>> violations = validator.validate(item);
    if (!violations.isEmpty()) {
        throw new ConstraintViolationException(violations);
    }
}

}

==> kubernetes-model-1.0.51-sources.jar: io/fabric8/kubernetes/api/model/ConfigMapKeySelectorBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class ConfigMapKeySelectorBuilder extends ConfigMapKeySelectorFluentImpl<ConfigMapKeySelectorBuilder> implements VisitableBuilder<ConfigMapKeySelector,ConfigMapKeySelectorBuilder>{

     ConfigMapKeySelectorFluent<?> fluent;
public ConfigMapKeySelectorBuilder(){
    this(new ConfigMapKeySelector());
}
public ConfigMapKeySelectorBuilder( ConfigMapKeySelectorFluent<?> fluent ){
    this(fluent, new ConfigMapKeySelector());
}
public ConfigMapKeySelectorBuilder( ConfigMapKeySelectorFluent<?> fluent , ConfigMapKeySelector instance ){
    this.fluent = fluent; fluent.withKey(instance.getKey()); fluent.withName(instance.getName()); 
}
public ConfigMapKeySelectorBuilder( ConfigMapKeySelector instance ){
    this.fluent = this; this.withKey(instance.getKey()); this.withName(instance.getName()); 
}

public ConfigMapKeySelector build(){
    ConfigMapKeySelector buildable = new ConfigMapKeySelector(fluent.getKey(),fluent.getName());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
ConfigMapKeySelectorBuilder that = (ConfigMapKeySelectorBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
